@@ -28,14 +28,42 @@ class API:
 
         self.logging = logging
         self.url = f"{protocol}://{host}:{port}"
+        self.key = kwargs.get("key", ".")
 
         # Validate if the server is up
         try:
-            requests.get(self.url)
+            r = requests.get(self.endpoint, json={"__key__": self.key})
+            if r.status_code in [401, 403]:
+                raise APIKeyError(self.key)
         except requests.exceptions.RequestException as e:
             raise ConnectionError(f"Failed to connect to jarvis' server. Please check your url. ({e})")
+    
+    @property
+    def endpoint(self) -> str:
+        return self.url + "/api/"
+    
+    def changeBase(self, host: str, port: str, protocol: str = "http") -> None:
+        """
+        Change the base url.
+
+        Parameters
+        ----------
+        `host` : str
+        `port` : str
+        `protocol` : str = "http"
+
+        Raises
+        ------
+        `ConnectionError` : When changing the base url failed because it is not valid or available.
+        """
+
+        url = f"{protocol}://{host}:{port}"
+        try:
+            requests.get(url)
+        except requests.exceptions.RequestException:
+            raise ConnectionError(f"Failed to change base url to {url}")
         
-        self.endpoint = self.url + "/api/v1/"
+        self.url = url
     
     async def request(self, url: str, method: str = "post", **kwargs) -> APIResponse:
         """
@@ -61,6 +89,9 @@ class API:
                 "post": s.post,
                 "get": s.get
             }
+        
+        json_ = kwargs.pop("json", {})
+        json_["__key__"] = self.key
 
         async with aiohttp.ClientSession() as session:
             method_ = mappings(session).get(method)
@@ -68,14 +99,20 @@ class API:
                 raise InvalidMethod(f"{method} is not a valid method.")
             
             try:
-                async with method_(url, **kwargs) as r:
-                    return APIResponse(
+                async with method_(url, json=json_, **kwargs) as r:
+                    r = APIResponse(
                         r.status,
                         r.reason,
                         r.content_type,
                         await r.json()
                     )
-            except aiohttp.ClientResponseError as e:
+
+                    if r.status in [401, 403]:
+                        raise APIKeyError(self.key)
+                    
+                    return r
+
+            except Exception as e:
                 raise APIRequestFailed(f"URL: {url} ({e})")
             
     async def play(self, name: str, cls: str = None, **kwargs) -> dict:
